isl: Sets and relations of integer points bounded by affine constraints
=======================================================================

Description
-----------

isl is a thread-safe C library for manipulating sets and relations of
integer points bounded by affine constraints. The descriptions of the
sets and relations may involve both parameters and existentially
quantified variables. All computations are performed in exact integer
arithmetic using GMP.

License
-------

isl is released under the MIT license, but depends on the LGPL GMP
library.


Upstream Contact
----------------

-  http://groups.google.com/group/isl-development

Citation
--------

::

  @incollection{Verdoolaege2010isl,
     author = {Verdoolaege, Sven},
     title = {isl: An Integer Set Library for the Polyhedral Model},
     booktitle = {Mathematical Software - ICMS 2010},
     series = {Lecture Notes in Computer Science},
     editor = {Fukuda, Komei and Hoeven, Joris and Joswig, Michael and
     Takayama, Nobuki},
     publisher = {Springer},
     isbn = {978-3-642-15581-9},
     pages = {299-302},
     volume = {6327},
     year = {2010}
  }
